@@ -232,7 +232,7 @@ gint gigolo_bookmark_edit_dialog_run(GigoloBookmarkEditDialog *dialog)
 					}
 				}
 			}
-			if (! error && gtk_widget_get_parent(priv->host_entry) != NULL)
+			if (gtk_widget_is_visible(priv->host_entry) && ! error && gtk_widget_get_parent(priv->host_entry) != NULL)
 			{
 				tmp = gtk_entry_get_text(GTK_ENTRY(priv->host_entry));
 				if (! *tmp)
@@ -391,9 +391,7 @@ static void init_values(GigoloBookmarkEditDialog *dialog)
 	GigoloBookmarkEditDialogPrivate *priv = gigolo_bookmark_edit_dialog_get_instance_private(dialog);
 	gchar *uri, *user;
 	const gchar *tmp;
-	guint port;
 	guint idx;
-
 	/* Name */
 	tmp = gigolo_bookmark_get_name(priv->bookmark_init);
 	if (tmp != NULL)
@@ -454,8 +452,6 @@ static void init_values(GigoloBookmarkEditDialog *dialog)
 	tmp = gigolo_bookmark_get_path(priv->bookmark_init);
 	if (tmp != NULL)
 		gtk_entry_set_text(GTK_ENTRY(priv->path_entry), tmp);
-	/* Port */
-	port = gigolo_bookmark_get_port(priv->bookmark_init);
 
 	idx = scheme_to_index(gigolo_bookmark_get_scheme(priv->bookmark_init));
 
@@ -463,10 +459,6 @@ static void init_values(GigoloBookmarkEditDialog *dialog)
 		GTK_SWITCH(priv->autoconnect_switch),
 		gigolo_bookmark_get_autoconnect(priv->bookmark_init));
 
-	if (port == 0)
-		port = methods[idx].port;
-	gtk_spin_button_set_value(GTK_SPIN_BUTTON(priv->port_spin), port);
-
 	combo_set_active(priv->type_combo, idx);
 }
 
@@ -475,7 +467,7 @@ static void setup_for_type(GigoloBookmarkEditDialog *dialog)
 {
 	struct MethodInfo *meth;
 	guint idx;
-	GtkWidget *table;
+	guint port = 0;
 	GtkTreeIter iter;
 	GigoloBookmarkEditDialogPrivate *priv = gigolo_bookmark_edit_dialog_get_instance_private(dialog);
 
@@ -486,7 +478,6 @@ static void setup_for_type(GigoloBookmarkEditDialog *dialog)
 			    &iter, COLUMN_INDEX, &idx, -1);
 	g_return_if_fail(idx < methods_len);
 	meth = &(methods[idx]);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (priv->port_spin), meth->port);
 
 	gtk_widget_hide (priv->uri_label);
 	gtk_widget_hide (priv->uri_entry);
@@ -524,6 +515,11 @@ static void setup_for_type(GigoloBookmarkEditDialog *dialog)
 	}
 	else
 	{
+		port = meth->port;
+		if (priv->bookmark_init && idx == scheme_to_index(gigolo_bookmark_get_scheme(priv->bookmark_init)))
+			port = gigolo_bookmark_get_port(priv->bookmark_init);
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(priv->port_spin), port);
+
 		if (meth->flags & SHOW_DEVICE)
 			gtk_label_set_text_with_mnemonic(GTK_LABEL(priv->host_label), _("_Device:"));
 		else
@@ -904,7 +900,7 @@ static GtkWidget *make_frame (const gchar *label)
 }
 
 
-static GtkWidget *make_table ()
+static GtkWidget *make_table (void)
 {
 	GtkWidget *table = gtk_grid_new ();
 	gtk_grid_set_row_spacing (GTK_GRID (table), 6);
@@ -927,7 +923,6 @@ static GtkWidget *make_label (const gchar *text, GtkSizeGroup *sg)
 static void gigolo_bookmark_edit_dialog_init(GigoloBookmarkEditDialog *dialog)
 {
 	GtkWidget *label;
-	GtkWidget *label_tmp;
 	GtkWidget *table;
 	GtkWidget *combo;
 	GtkWidget *entry;
