@@ -25,7 +25,6 @@
 #include <string.h>
 
 #include "common.h"
-#include "compat.h"
 #include "bookmark.h"
 #include "settings.h"
 #include "backendgvfs.h"
@@ -62,7 +61,7 @@ static GtkWidget *xfce_header_new(const gchar *icon, const gchar *title)
 
 	xfce_heading = gtk_event_box_new();
 	entry = gtk_entry_new();
-	hbox = gtk_hbox_new(FALSE, 12);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 6);
 	image = gtk_image_new_from_icon_name(icon, GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 0);
@@ -75,10 +74,10 @@ static GtkWidget *xfce_header_new(const gchar *icon, const gchar *title)
 
 	gtk_widget_destroy(entry);
 
-	vbox = gtk_vbox_new(FALSE, 0);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), xfce_heading, FALSE, FALSE, 0);
 
-	separator = gtk_hseparator_new();
+	separator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start(GTK_BOX(vbox), separator, FALSE, FALSE, 0);
 
 	return vbox;
@@ -143,11 +142,11 @@ static GtkWidget *add_toolbar_style_combo(GigoloSettings *settings, const gchar
 
 	g_object_get(settings, property, &value, NULL);
 
-	widget = gtk_combo_box_new_text();
-	gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Icons"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Text"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Both"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Both horizontal"));
+	widget = gtk_combo_box_text_new();
+	gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(widget), NULL, _("Icons"));
+	gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(widget), NULL, _("Text"));
+	gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(widget), NULL, _("Both"));
+	gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(widget), NULL, _("Both horizontal"));
 
 	gtk_combo_box_set_active(GTK_COMBO_BOX(widget), value);
 
@@ -165,9 +164,9 @@ static GtkWidget *add_toolbar_orientation_combo(GigoloSettings *settings, const
 
 	g_object_get(settings, property, &value, NULL);
 
-	widget = gtk_combo_box_new_text();
-	gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Horizontal"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Vertical"));
+	widget = gtk_combo_box_text_new();
+	gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(widget), NULL, _("Horizontal"));
+	gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(widget), NULL, _("Vertical"));
 
 	gtk_combo_box_set_active(GTK_COMBO_BOX(widget), value);
 
@@ -185,9 +184,9 @@ static GtkWidget *add_view_mode_combo(GigoloSettings *settings, const gchar *pro
 
 	g_object_get(settings, property, &value, NULL);
 
-	widget = gtk_combo_box_new_text();
-	gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Symbols"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Detailed List"));
+	widget = gtk_combo_box_text_new();
+	gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(widget), NULL, _("Symbols"));
+	gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(widget), NULL, _("Detailed List"));
 
 	gtk_combo_box_set_active(GTK_COMBO_BOX(widget), value);
 
@@ -222,11 +221,11 @@ static void entry_check_input(GtkEntry *entry)
 			gtk_image_set_from_icon_name(icon, first_part, GTK_ICON_SIZE_MENU);
 		}
 		else
-			gtk_image_set_from_stock(icon, GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
+			gtk_image_set_from_icon_name(icon, "gtk-execute", GTK_ICON_SIZE_MENU);
 		g_free(path);
 	}
 	else
-		gtk_image_set_from_stock(icon, GTK_STOCK_STOP, GTK_ICON_SIZE_MENU);
+		gtk_image_set_from_icon_name(icon, "gtk-stop", GTK_ICON_SIZE_MENU);
 
 	g_free(first_part);
 
@@ -304,13 +303,12 @@ static GtkWidget *add_spinbutton(GigoloSettings *settings, const gchar *property
 
 static void set_settings(GigoloPreferencesDialog *dialog, GigoloSettings *settings)
 {
-	GtkWidget *frame_vbox, *notebook_vbox, *vbox, *hbox, *notebook;
+	GtkWidget *frame_grid, *notebook_vbox, *vbox, *hbox, *notebook;
 	GtkWidget *checkbox, *combo, *entry, *combo_toolbar_style, *tmp_box;
 	GtkWidget *combo_toolbar_orient, *spinbutton;
-	GtkWidget *label1, *label2, *label3, *label4, *image;
-	GtkSizeGroup *sg;
+	GtkWidget *label, *image;
 
-    vbox = gigolo_dialog_get_content_area(GTK_DIALOG(dialog));
+    vbox = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
 
 	if (gigolo_is_desktop_xfce())
     {
@@ -323,21 +321,24 @@ static void set_settings(GigoloPreferencesDialog *dialog, GigoloSettings *settin
 
 	notebook = gtk_notebook_new();
 	gtk_box_pack_start(GTK_BOX(vbox), notebook, FALSE, TRUE, 0);
-	gtk_container_set_border_width(GTK_CONTAINER(notebook), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(notebook), 6);
 
 #define PAGE_GENERAL
-	notebook_vbox = gtk_vbox_new(FALSE, 2);
-	frame_vbox = gtk_vbox_new(FALSE, 5);
-	gtk_container_set_border_width(GTK_CONTAINER(frame_vbox), 5);
-	gtk_box_pack_start(GTK_BOX(notebook_vbox), frame_vbox, TRUE, TRUE, 5);
+	notebook_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+	frame_grid = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (frame_grid), 6);
+	gtk_grid_set_column_spacing (GTK_GRID (frame_grid), 12);
+	gtk_container_set_border_width(GTK_CONTAINER(frame_grid), 12);
+	gtk_box_pack_start(GTK_BOX(notebook_vbox), frame_grid, TRUE, TRUE, 0);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), notebook_vbox, gtk_label_new(_("General")));
 
-	hbox = gtk_hbox_new(FALSE, 6);
-	gtk_box_pack_start(GTK_BOX(frame_vbox), hbox, FALSE, FALSE, 0);
+	/* Row */
+	label = gtk_label_new_with_mnemonic(_("_File Manager"));
+	gtk_label_set_xalign(GTK_LABEL(label), 0);
+	gtk_grid_attach (GTK_GRID (frame_grid), label, 0, 0, 1, 1);
 
-	label1 = gtk_label_new_with_mnemonic(_("_File Manager"));
-	gtk_misc_set_alignment(GTK_MISC(label1), 0.0f, 0.5f);
-	gtk_box_pack_start(GTK_BOX(hbox), label1, FALSE, FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
+	gtk_grid_attach (GTK_GRID (frame_grid), hbox, 1, 0, 2, 1);
 
 	image = gtk_image_new();
 	gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 3);
@@ -345,16 +346,17 @@ static void set_settings(GigoloPreferencesDialog *dialog, GigoloSettings *settin
 	entry = add_program_entry(settings, "file-manager");
 	gtk_widget_set_tooltip_text(entry, _("Enter the name of a program to use to open or view mount points"));
 	g_object_set_data(G_OBJECT(entry), "image", image);
-	gtk_label_set_mnemonic_widget(GTK_LABEL(label1), entry);
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), entry);
 	gtk_box_pack_start(GTK_BOX(hbox), entry, FALSE, FALSE, 0);
 	entry_check_input(GTK_ENTRY(entry));
 
-	hbox = gtk_hbox_new(FALSE, 6);
-	gtk_box_pack_start(GTK_BOX(frame_vbox), hbox, FALSE, FALSE, 0);
+	/* Row */
+	label = gtk_label_new_with_mnemonic(_("_Terminal"));
+	gtk_label_set_xalign(GTK_LABEL(label), 0);
+	gtk_grid_attach (GTK_GRID (frame_grid), label, 0, 1, 1, 1);
 
-	label1 = gtk_label_new_with_mnemonic(_("_Terminal"));
-	gtk_misc_set_alignment(GTK_MISC(label1), 0.0f, 0.5f);
-	gtk_box_pack_start(GTK_BOX(hbox), label1, FALSE, FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
+	gtk_grid_attach (GTK_GRID (frame_grid), hbox, 1, 1, 2, 1);
 
 	image = gtk_image_new();
 	gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 3);
@@ -362,105 +364,92 @@ static void set_settings(GigoloPreferencesDialog *dialog, GigoloSettings *settin
 	entry = add_program_entry(settings, "terminal");
 	gtk_widget_set_tooltip_text(entry, _("Enter the name of a program to open mount points in a terminal"));
 	g_object_set_data(G_OBJECT(entry), "image", image);
-	gtk_label_set_mnemonic_widget(GTK_LABEL(label1), entry);
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), entry);
 	gtk_box_pack_start(GTK_BOX(hbox), entry, FALSE, FALSE, 0);
 	entry_check_input(GTK_ENTRY(entry));
 
-	hbox = gtk_hbox_new(FALSE, 6);
-	gtk_box_pack_start(GTK_BOX(frame_vbox), hbox, FALSE, FALSE, 0);
-
-	label1 = gtk_label_new_with_mnemonic(_("_Bookmark Auto-Connect Interval"));
-	gtk_misc_set_alignment(GTK_MISC(label1), 0.0f, 0.5f);
-	gtk_box_pack_start(GTK_BOX(hbox), label1, FALSE, FALSE, 0);
+	/* Row */
+	label = gtk_label_new_with_mnemonic(_("_Bookmark Auto-Connect Interval"));
+	gtk_label_set_xalign(GTK_LABEL(label), 0);
+	gtk_grid_attach (GTK_GRID (frame_grid), label, 0, 2, 2, 1);
 
 	spinbutton = add_spinbutton(settings, "autoconnect-interval");
 	gtk_widget_set_tooltip_text(spinbutton,
 		_("How often to try auto connecting bookmarks, in seconds. Zero disables checking."));
-	gtk_label_set_mnemonic_widget(GTK_LABEL(label1), spinbutton);
-	gtk_box_pack_start(GTK_BOX(hbox), spinbutton, FALSE, FALSE, 10);
-
-	gtk_box_pack_start(GTK_BOX(frame_vbox), gtk_label_new(""), FALSE, FALSE, 0);
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), spinbutton);
+	gtk_grid_attach (GTK_GRID (frame_grid), spinbutton, 2, 2, 1, 1);
 
 #define PAGE_INTERFACE
-	notebook_vbox = gtk_vbox_new(FALSE, 2);
-	frame_vbox = gtk_vbox_new(FALSE, 5);
-	gtk_container_set_border_width(GTK_CONTAINER(frame_vbox), 5);
-	gtk_box_pack_start(GTK_BOX(notebook_vbox), frame_vbox, TRUE, TRUE, 5);
+	notebook_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+	frame_grid = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (frame_grid), 6);
+	gtk_grid_set_column_spacing (GTK_GRID (frame_grid), 12);
+	gtk_container_set_border_width(GTK_CONTAINER(frame_grid), 12);
+	gtk_box_pack_start(GTK_BOX(notebook_vbox), frame_grid, TRUE, TRUE, 0);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), notebook_vbox, gtk_label_new(_("Interface")));
 
 	checkbox = add_check_button(settings, "save-geometry", _("_Save window position and geometry"));
 	gtk_widget_set_tooltip_text(checkbox, _("Saves the window position and geometry and restores it at the start"));
-	gtk_box_pack_start(GTK_BOX(frame_vbox), checkbox, FALSE, FALSE, 0);
+	gtk_grid_attach (GTK_GRID (frame_grid), checkbox, 0, 0, 2, 1);
 
 	tmp_box = checkbox = add_check_button(settings, "show-in-systray", _("Show status _icon in the Notification Area"));
-	gtk_box_pack_start(GTK_BOX(frame_vbox), checkbox, FALSE, FALSE, 0);
+	gtk_grid_attach (GTK_GRID (frame_grid), checkbox, 0, 1, 2, 1);
 
 	checkbox = add_check_button(settings, "start-in-systray", _("Start _minimized in the Notification Area"));
-	gtk_box_pack_start(GTK_BOX(frame_vbox), checkbox, FALSE, FALSE, 0);
+	gtk_grid_attach (GTK_GRID (frame_grid), checkbox, 0, 2, 2, 1);
 	g_signal_connect(tmp_box, "toggled", G_CALLBACK(check_button_toggle_sensitive_cb), checkbox);
 	check_button_toggle_sensitive_cb(GTK_TOGGLE_BUTTON(tmp_box), checkbox);
 
 	checkbox = add_check_button(settings, "show-panel", _("Show side panel"));
 	gtk_widget_set_tooltip_text(checkbox, _("Whether to show a side panel for browsing the local network for available Samba/Windows shares and a bookmark list"));
-	gtk_box_pack_start(GTK_BOX(frame_vbox), checkbox, FALSE, FALSE, 0);
+	gtk_grid_attach (GTK_GRID (frame_grid), checkbox, 0, 3, 2, 1);
 
 	checkbox = add_check_button(settings, "show-autoconnect-errors", _("Show auto-connect error messages"));
 	gtk_widget_set_tooltip_text(checkbox, _("Whether to show error message dialogs when auto-connecting of bookmarks fails"));
-	gtk_box_pack_start(GTK_BOX(frame_vbox), checkbox, FALSE, FALSE, 0);
+	gtk_grid_attach (GTK_GRID (frame_grid), checkbox, 0, 4, 2, 1);
 
-	hbox = gtk_hbox_new(FALSE, 6);
-	gtk_box_pack_start(GTK_BOX(frame_vbox), hbox, FALSE, FALSE, 0);
-
-	label4 = gtk_label_new_with_mnemonic(_("_Connection List Mode"));
-	gtk_misc_set_alignment(GTK_MISC(label4), 0.0f, 0.5f);
-	gtk_box_pack_start(GTK_BOX(hbox), label4, FALSE, FALSE, 0);
+	label = gtk_label_new_with_mnemonic(_("_Connection List Mode"));
+	gtk_label_set_xalign(GTK_LABEL(label), 0);
+	gtk_widget_set_hexpand (GTK_WIDGET (label), TRUE);
+	gtk_grid_attach (GTK_GRID (frame_grid), label, 0, 5, 1, 1);
 
 	combo = add_view_mode_combo(settings, "view-mode");
-	gtk_label_set_mnemonic_widget(GTK_LABEL(label4), combo);
-	gtk_box_pack_start(GTK_BOX(hbox), combo, FALSE, FALSE, 0);
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), combo);
+	gtk_grid_attach (GTK_GRID (frame_grid), combo, 1, 5, 1, 1);
 
 #define PAGE_TOOLBAR
-	notebook_vbox = gtk_vbox_new(FALSE, 2);
-	frame_vbox = gtk_vbox_new(FALSE, 5);
-	gtk_container_set_border_width(GTK_CONTAINER(frame_vbox), 5);
-	gtk_box_pack_start(GTK_BOX(notebook_vbox), frame_vbox, TRUE, TRUE, 5);
+	notebook_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 2);
+	frame_grid = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (frame_grid), 6);
+	gtk_grid_set_column_spacing (GTK_GRID (frame_grid), 12);
+	gtk_container_set_border_width(GTK_CONTAINER(frame_grid), 12);
+	gtk_box_pack_start(GTK_BOX(notebook_vbox), frame_grid, TRUE, TRUE, 0);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), notebook_vbox, gtk_label_new(_("Toolbar")));
 
 	checkbox = add_check_button(settings, "show-toolbar", _("Show _toolbar"));
-	gtk_box_pack_start(GTK_BOX(frame_vbox), checkbox, FALSE, FALSE, 0);
+	gtk_grid_attach (GTK_GRID (frame_grid), checkbox, 0, 0, 2, 1);
 
-	hbox = gtk_hbox_new(FALSE, 6);
-	gtk_box_pack_start(GTK_BOX(frame_vbox), hbox, FALSE, FALSE, 0);
-
-	label2 = gtk_label_new_with_mnemonic(_("St_yle"));
-	gtk_misc_set_alignment(GTK_MISC(label2), 0.0f, 0.5f);
-	gtk_box_pack_start(GTK_BOX(hbox), label2, FALSE, FALSE, 0);
+	label = gtk_label_new_with_mnemonic(_("St_yle"));
+	gtk_label_set_xalign(GTK_LABEL(label), 0);
+	gtk_widget_set_hexpand (GTK_WIDGET (label), TRUE);
+	gtk_grid_attach (GTK_GRID (frame_grid), label, 0, 1, 1, 1);
 
 	combo_toolbar_style = add_toolbar_style_combo(settings, "toolbar-style");
-	gtk_label_set_mnemonic_widget(GTK_LABEL(label2), combo_toolbar_style);
-	gtk_box_pack_start(GTK_BOX(hbox), combo_toolbar_style, FALSE, FALSE, 0);
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), combo_toolbar_style);
+	gtk_grid_attach (GTK_GRID (frame_grid), combo_toolbar_style, 1, 1, 1, 1);
 
-	hbox = gtk_hbox_new(FALSE, 6);
-	gtk_box_pack_start(GTK_BOX(frame_vbox), hbox, FALSE, FALSE, 0);
-
-	label3 = gtk_label_new_with_mnemonic(_("_Orientation"));
-	gtk_misc_set_alignment(GTK_MISC(label3), 0.0f, 0.5f);
-	gtk_box_pack_start(GTK_BOX(hbox), label3, FALSE, FALSE, 0);
+	label = gtk_label_new_with_mnemonic(_("_Orientation"));
+	gtk_label_set_xalign(GTK_LABEL(label), 0);
+	gtk_grid_attach (GTK_GRID (frame_grid), label, 0, 2, 1, 1);
 
 	combo_toolbar_orient = add_toolbar_orientation_combo(settings, "toolbar-orientation");
-	gtk_label_set_mnemonic_widget(GTK_LABEL(label3), combo_toolbar_orient);
-	gtk_box_pack_start(GTK_BOX(hbox), combo_toolbar_orient, FALSE, FALSE, 0);
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), combo_toolbar_orient);
+	gtk_grid_attach (GTK_GRID (frame_grid), combo_toolbar_orient, 1, 2, 1, 1);
 
 	g_object_set_data(G_OBJECT(checkbox), "combo_toolbar_style", combo_toolbar_style);
 	g_object_set_data(G_OBJECT(checkbox), "combo_toolbar_orient", combo_toolbar_orient);
 	g_signal_connect(checkbox, "toggled", G_CALLBACK(check_toolbar_show_toggle_cb), settings);
 
-	sg = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
-	gtk_size_group_add_widget(sg, label2);
-	gtk_size_group_add_widget(sg, label3);
-	g_object_unref(sg);
-
-
 	gtk_widget_show_all(vbox);
 }
 
@@ -503,11 +492,10 @@ static void gigolo_preferences_dialog_class_init(GigoloPreferencesDialogClass *k
 static void gigolo_preferences_dialog_init(GigoloPreferencesDialog *dialog)
 {
     g_object_set(dialog,
-		"icon-name", GTK_STOCK_PREFERENCES,
+		"icon-name", "gtk-preferences",
 		"title", _("Preferences"),
-		"has-separator", FALSE,
 		NULL);
-	gtk_dialog_add_buttons(GTK_DIALOG(dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
+	gtk_dialog_add_buttons(GTK_DIALOG(dialog), "gtk-close", GTK_RESPONSE_CLOSE, NULL);
 }
 
 
